==> graphql-io-server-1.7.0.tgz: package/lib/graphql-io-1-server.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.default = void 0;

var _promise = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/promise"));

var _parseInt2 = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/parse-int"));

var _fs = _interopRequireDefault(require("mz/fs"));

var _stdapi = _interopRequireDefault(require("stdapi"));

var _pureUuid = _interopRequireDefault(require("pure-uuid"));

var _hapi = _interopRequireDefault(require("hapi"));

var _http = _interopRequireDefault(require("http"));

var _http2 = _interopRequireDefault(require("http2"));

var _urijs = _interopRequireDefault(require("urijs"));

var _inert = _interopRequireDefault(require("inert"));

var _hapiAuthBasic = _interopRequireDefault(require("hapi-auth-basic"));

var _hapiBoomDecorators = _interopRequireDefault(require("hapi-boom-decorators"));

var _hapiPluginDucky = _interopRequireDefault(require("hapi-plugin-ducky"));

var _hapiPluginHeader = _interopRequireDefault(require("hapi-plugin-header"));

var _hapiPluginWebsocket = _interopRequireDefault(require("hapi-plugin-websocket"));

var _hapiPluginCo = _interopRequireDefault(require("hapi-plugin-co"));

var _hapiPluginTraffic = _interopRequireDefault(require("hapi-plugin-traffic"));

var _hapiPluginPeer = _interopRequireDefault(require("hapi-plugin-peer"));

var _generatePassword = _interopRequireDefault(require("generate-password"));

var _hapiAuthJwt = _interopRequireDefault(require("hapi-auth-jwt2"));

var _jsonwebtoken = _interopRequireDefault(require("jsonwebtoken"));

var _commonPathPrefix = _interopRequireDefault(require("common-path-prefix"));

var _graphqlIo2Ui = _interopRequireDefault(require("./graphql-io-2-ui"));

var _graphqlIo3Auth = _interopRequireDefault(require("./graphql-io-3-auth"));

var _graphqlIo4Graphql = _interopRequireDefault(require("./graphql-io-4-graphql"));

var _graphqlIo5Blob = _interopRequireDefault(require("./graphql-io-5-blob"));

/*
**  GraphQL-IO -- GraphQL Network Communication Framework
**  Copyright (c) 2016-2019 Dr. Ralf S. Engelschall <rse@engelschall.com>
**
**  Permission is hereby granted, free of charge, to any person obtaining
**  a copy of this software and associated documentation files (the
**  "Software"), to deal in the Software without restriction, including
**  without limitation the rights to use, copy, modify, merge, publish,
**  distribute, sublicense, and/or sell copies of the Software, and to
**  permit persons to whom the Software is furnished to do so, subject to
**  the following conditions:
**
**  The above copyright notice and this permission notice shall be included
**  in all copies or substantial portions of the Software.
**
**  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
**  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
**  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
**  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
**  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
**  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
**  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

/*  external dependencies  */

/*  internal dependencies  */

/*  the exported API class  */
class Server extends _stdapi.default {
  constructor(options) {
    super(options, {
      prefix: ["string", "GraphQL-IO-"],
      name: ["string", "GraphQL-IO-Server"],
      url: ["/^https?:\\/\\/.+?(?::\\d+)?$/", "http://127.0.0.1:8080"],
      path: {
        frontend: ["/^\\/.*$/", "/"],
        graphiql: ["/^\\/.+$/", "/api"],
        login: ["/^\\/.+$/", "/api/auth/login"],
        session: ["/^\\/.+$/", "/api/auth/session"],
        logout: ["/^\\/.+$/", "/api/auth/logout"],
        graph: ["/^\\/.+$/", "/api/data/graph"],
        blob: ["/^\\/.+$/", "/api/data/blob"]
      },
      tls: {
        crt: ["string", ""],
        key: ["string", ""]
      },
      secret: ["string", _generatePassword.default.generate({
        length: 16,
        numbers: true
      })],
      ttl: ["number", 7 * 24 * 60 * 60 * 1000],
      samesite: ["/^(none|Strict|Lax)$/", "Strict"],
      throttle: ["number", 50],
      pubsub: ["string", "spm:xxx"],
      keyval: ["string", "spm:xxx"],
      frontend: ["string", ""],
      graphiql: ["boolean", true],
      encoding: ["/^(?:cbor|msgpack|json)$/", "json"],
      debug: ["number", 0],
      example: ["string", "query Example {\n" + "    _Server {\n" + "        name\n" + "        version\n" + "    }\n" + "}\n"]
    });
    /*  initialize internal state  */

    this._.nsUUID = new _pureUuid.default(5, "ns:URL", "http://graphql-io.com/ns/");
    this._.server = null;
    this._.prefix = null;
  }
  /*  start the service  */


  async start() {
    /*  give others still a chance to reconfigure us  */
    await this.hook("server-configure", "promise", this);
    /*  determine common URL path prefix  */

    this._.prefix = (0, _commonPathPrefix.default)([this.$.path.login, this.$.path.session, this.$.path.logout, this.$.path.graph, this.$.path.blob], "/");
    if (this._.prefix === "") this._.prefix = "/";
    /*  parse the URL  */

    this._.url = _urijs.default.parse(this.$.url);
    if (this._.url.port === null) this._.url.port = this._.url.protocol === "https" ? 443 : 80;
    if (typeof this._.url.port === "string") this._.url.port = (0, _parseInt2.default)(this._.url.port);
    let withTLS = this.$.tls.crt !== "" && this.$.tls.key !== "";
    if (!withTLS && this._.url.protocol === "https") throw new Error("HTTPS requires TLS Certificate/Key");
    /*  create underlying HTTP/HTTPS listener  */

    let listener;

    if (withTLS) {
      let crt = await _fs.default.readFile(this.$.tls.crt, "utf8");
      let key = await _fs.default.readFile(this.$.tls.key, "utf8");
      listener = _http2.default.createServer({
        key: key,
        cert: crt
      });
    } else listener = _http.default.createServer();

    if (!listener.address) listener.address = function () {
      return this._server.address();
    };
    /*  configure the listening socket  */

    let hapiOpts = {
      listener: listener,
      autoListen: false
    };
    if (withTLS) hapiOpts.tls = true;
    /*  establish a new server context  */

    let server = new _hapi.default.Server(hapiOpts);
    this._.server = server;
    /*  start listening  */

    listener.listen(this._.url.port, this._.url.hostname);
    this._.listener = listener;
    /*  register HAPI plugins  */

    await server.register({
      plugin: _inert.default
    });
    await server.register({
      plugin: _hapiAuthBasic.default
    });
    await server.register({
      plugin: _hapiBoomDecorators.default
    });
    await server.register({
      plugin: _hapiPluginDucky.default
    });
    await server.register({
      plugin: _hapiPluginHeader.default,
      options: {
        Server: this.$.name
      }
    });
    await server.register({
      plugin: _hapiPluginWebsocket.default
    });
    await server.register({
      plugin: _hapiPluginCo.default
    });
    await server.register({
      plugin: _hapiPluginTraffic.default
    });
    await server.register({
      plugin: _hapiPluginPeer.default,
      options: {
        peerId: true,
        cookieName: `${this.$.prefix}Peer`,
        cookieOptions: {
          ttl: this.$.ttl,
          path: this._.prefix,
          encoding: "none",
          isHttpOnly: true,
          isSecure: false,
          clearInvalid: false,
          strictHeader: true,
          isSameSite: this.$.samesite !== "none" ? this.$.samesite : false
        }
      }
    });
    /*  provide client IP address  */

    server.ext("onRequest", async (request, h) => {
      let clientAddress = "<unknown>";
      if (request.headers["x-forwarded-for"]) clientAddress = request.headers["x-forwarded-for"].replace(/^(\S+)(?:,\s*\S+)*$/, "$1");else clientAddress = request.info.remoteAddress;
      request.app.clientAddress = clientAddress;
      return h.continue;
    });
    /*  prepare for JSONWebToken (JWT) authentication  */

    let jwtKey = this.$.secret;
    await server.register({
      plugin: _hapiAuthJwt.default
    });
    server.auth.strategy("jwt", "jwt", {
      key: jwtKey,
      verifyOptions: {
        algorithms: ["HS256"]
      },
      urlKey: `${this.$.prefix}Token`,
      cookieKey: `${this.$.prefix}Token`,
      tokenType: "JWT",
      validate: (decoded, request, h) => {
        let result = this.hook("jwt-validate", "pass", {
          error: null,
          result: true
        }, decoded, request);
        return {
          isValid: result.result,
          error: result.error
        };
      }
    });

    this._.jwtSign = (data, expires) => _jsonwebtoken.default.sign(data, jwtKey, {
      algorithm: "HS256",
      expiresIn: expires || "365d"
    });
    /*  log all requests  */


    server.events.on("response", request => {
      let traffic = request.traffic();
      let protocol = `HTTP/${request.raw.req.httpVersion}`;
      let ws = request.websocket();

      if (ws.mode === "websocket") {
        let wsVersion = ws.ws.protocolVersion || request.headers["sec-websocket-version"] || "13?";
        protocol = `WebSocket/${wsVersion}+${protocol}`;
      }

      let msg = "request: " + "remote=" + `${request.app.clientAddress}:${request.info.remotePort}` + ", " + "method=" + request.method.toUpperCase() + ", " + "url=" + request.url.path + ", " + "protocol=" + protocol + ", " + "response=" + (request.response ? request.response.statusCode : "<unknown>") + ", " + "recv=" + traffic.recvPayload + "/" + traffic.recvRaw + ", " + "sent=" + traffic.sentPayload + "/" + traffic.sentRaw + ", " + "duration=" + traffic.timeDuration;
      this.debug(2, `HAPI: request: ${msg}`);
    });
    server.events.on({
      name: "request",
      channels: ["error"]
    }, (request, event, tags) => {
      if (event.error instanceof Error) this.debug(2, `HAPI: request-error: ${event.error.message}`);else this.debug(2, `HAPI: request-error: ${event.error}`);
    });
    server.events.on("log", (event, tags) => {
      if (tags.error) {
        let err = event.error;
        if (err instanceof Error) this.debug(2, `HAPI: log: ${err.message}`);else this.debug(2, `HAPI: log: ${err}`);
      }
    });
    /*  display network interaction information  */

    const displayListenHint = ([scheme, proto]) => {
      let url = `${scheme}://${this._.url.hostname}:${this._.url.port}`;
      this.debug(1, `HAPI: listen on ${url} (${proto})`);
    };

    displayListenHint(withTLS ? ["https", "HTTP/{1.0,1.1,2.0} + SSL/TLS"] : ["http", "HTTP/{1.0,1.1}"]);
    displayListenHint(withTLS ? ["wss", "WebSockets + SSL/TLS"] : ["ws", "WebSockets"]);
    /*  setup services  */

    await _graphqlIo2Ui.default.start.call(this);
    await _graphqlIo3Auth.default.start.call(this);
    await _graphqlIo4Graphql.default.start.call(this);
    await _graphqlIo5Blob.default.start.call(this);
    /*  allow application to hook into  */

    await this.hook("server-start", "promise", server);
    /*  start the HAPI service  */

    return new _promise.default((resolve, reject) => {
      server.start().then(() => {
        this.debug(1, "HAPI: OK: started HAPI service");
        resolve();
      }).catch(err => {
        this.debug(1, "HAPI: ERROR: failed to start HAPI service");
        reject(err);
      });
    });
  }
  /*  stop the service  */


  async stop() {
    /*   stop the HAPI service  */
    this.debug(1, "HAPI: gracefully stopping HAPI service");
    await this._.server.stop({
      timeout: 4 * 1000
    });
    /*  allow application to hook into  */

    await this.hook("server-stop", "promise", this._.server);
    /*  teardown services  */

    await _graphqlIo5Blob.default.stop.call(this);
    await _graphqlIo4Graphql.default.stop.call(this);
    await _graphqlIo3Auth.default.stop.call(this);
    await _graphqlIo2Ui.default.stop.call(this);
    /*  stop listening  */

    this._.listener.close();
    /*  finally destroy HAPI instance  */


    this._.server = null;
  }

}

exports.default = Server;

==> graphql-io-server-1.8.0.tgz: package/lib/graphql-io-1-server.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.default = void 0;

var _promise = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/promise"));

var _parseInt2 = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/parse-int"));

var _fs = _interopRequireDefault(require("mz/fs"));

var _stdapi = _interopRequireDefault(require("stdapi"));

var _pureUuid = _interopRequireDefault(require("pure-uuid"));

var _http = _interopRequireDefault(require("http"));

var _http2 = _interopRequireDefault(require("http2"));

var _urijs = _interopRequireDefault(require("urijs"));

var _hapi = _interopRequireDefault(require("@hapi/hapi"));

var _inert = _interopRequireDefault(require("@hapi/inert"));

var _basic = _interopRequireDefault(require("@hapi/basic"));

var _hapiPluginDucky = _interopRequireDefault(require("hapi-plugin-ducky"));

var _hapiPluginHeader = _interopRequireDefault(require("hapi-plugin-header"));

var _hapiPluginWebsocket = _interopRequireDefault(require("hapi-plugin-websocket"));

var _hapiPluginCo = _interopRequireDefault(require("hapi-plugin-co"));

var _hapiPluginTraffic = _interopRequireDefault(require("hapi-plugin-traffic"));

var _hapiPluginPeer = _interopRequireDefault(require("hapi-plugin-peer"));

var _generatePassword = _interopRequireDefault(require("generate-password"));

var _hapiAuthJwt = _interopRequireDefault(require("hapi-auth-jwt2"));

var _jsonwebtoken = _interopRequireDefault(require("jsonwebtoken"));

var _commonPathPrefix = _interopRequireDefault(require("common-path-prefix"));

var _graphqlIo2Ui = _interopRequireDefault(require("./graphql-io-2-ui"));

var _graphqlIo3Auth = _interopRequireDefault(require("./graphql-io-3-auth"));

var _graphqlIo4Graphql = _interopRequireDefault(require("./graphql-io-4-graphql"));

var _graphqlIo5Blob = _interopRequireDefault(require("./graphql-io-5-blob"));

/*
**  GraphQL-IO -- GraphQL Network Communication Framework
**  Copyright (c) 2016-2019 Dr. Ralf S. Engelschall <rse@engelschall.com>
**
**  Permission is hereby granted, free of charge, to any person obtaining
**  a copy of this software and associated documentation files (the
**  "Software"), to deal in the Software without restriction, including
**  without limitation the rights to use, copy, modify, merge, publish,
**  distribute, sublicense, and/or sell copies of the Software, and to
**  permit persons to whom the Software is furnished to do so, subject to
**  the following conditions:
**
**  The above copyright notice and this permission notice shall be included
**  in all copies or substantial portions of the Software.
**
**  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
**  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
**  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
**  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
**  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
**  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
**  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

/*  external dependencies  */

/*  internal dependencies  */

/*  the exported API class  */
class Server extends _stdapi.default {
  constructor(options) {
    super(options, {
      prefix: ["string", "GraphQL-IO-"],
      name: ["string", "GraphQL-IO-Server"],
      url: ["/^https?:\\/\\/.+?(?::\\d+)?$/", "http://127.0.0.1:8080"],
      path: {
        frontend: ["/^\\/.*$/", "/"],
        graphiql: ["/^\\/.+$/", "/api"],
        login: ["/^\\/.+$/", "/api/auth/login"],
        session: ["/^\\/.+$/", "/api/auth/session"],
        logout: ["/^\\/.+$/", "/api/auth/logout"],
        graph: ["/^\\/.+$/", "/api/data/graph"],
        blob: ["/^\\/.+$/", "/api/data/blob"]
      },
      tls: {
        crt: ["string", ""],
        key: ["string", ""]
      },
      secret: ["string", _generatePassword.default.generate({
        length: 16,
        numbers: true
      })],
      ttl: ["number", 7 * 24 * 60 * 60 * 1000],
      samesite: ["/^(none|Strict|Lax)$/", "Strict"],
      throttle: ["number", 50],
      pubsub: ["string", "spm:xxx"],
      keyval: ["string", "spm:xxx"],
      frontend: ["string", ""],
      graphiql: ["boolean", true],
      encoding: ["/^(?:cbor|msgpack|json)$/", "json"],
      debug: ["number", 0],
      example: ["string", "query Example {\n" + "    _Server {\n" + "        name\n" + "        version\n" + "    }\n" + "}\n"]
    });
    /*  initialize internal state  */

    this._.nsUUID = new _pureUuid.default(5, "ns:URL", "http://graphql-io.com/ns/");
    this._.server = null;
    this._.prefix = null;
  }
  /*  start the service  */


  async start() {
    /*  give others still a chance to reconfigure us  */
    await this.hook("server-configure", "promise", this);
    /*  determine common URL path prefix  */

    this._.prefix = (0, _commonPathPrefix.default)([this.$.path.login, this.$.path.session, this.$.path.logout, this.$.path.graph, this.$.path.blob], "/");
    if (this._.prefix === "") this._.prefix = "/";
    /*  parse the URL  */

    this._.url = _urijs.default.parse(this.$.url);
    if (this._.url.port === null) this._.url.port = this._.url.protocol === "https" ? 443 : 80;
    if (typeof this._.url.port === "string") this._.url.port = (0, _parseInt2.default)(this._.url.port);
    let withTLS = this.$.tls.crt !== "" && this.$.tls.key !== "";
    if (!withTLS && this._.url.protocol === "https") throw new Error("HTTPS requires TLS Certificate/Key");
    /*  create underlying HTTP/HTTPS listener  */

    let listener;

    if (withTLS) {
      let crt = await _fs.default.readFile(this.$.tls.crt, "utf8");
      let key = await _fs.default.readFile(this.$.tls.key, "utf8");
      listener = _http2.default.createServer({
        key: key,
        cert: crt
      });
    } else listener = _http.default.createServer();

    if (!listener.address) listener.address = function () {
      return this._server.address();
    };
    /*  configure the listening socket  */

    let hapiOpts = {
      listener: listener,
      autoListen: false
    };
    if (withTLS) hapiOpts.tls = true;
    /*  establish a new server context  */

    let server = new _hapi.default.Server(hapiOpts);
    this._.server = server;
    /*  start listening  */

    listener.listen(this._.url.port, this._.url.hostname);
    this._.listener = listener;
    /*  register HAPI plugins  */

    await server.register({
      plugin: _inert.default
    });
    await server.register({
      plugin: _basic.default
    });
    await server.register({
      plugin: _hapiPluginDucky.default
    });
    await server.register({
      plugin: _hapiPluginHeader.default,
      options: {
        Server: this.$.name
      }
    });
    await server.register({
      plugin: _hapiPluginWebsocket.default
    });
    await server.register({
      plugin: _hapiPluginCo.default
    });
    await server.register({
      plugin: _hapiPluginTraffic.default
    });
    await server.register({
      plugin: _hapiPluginPeer.default,
      options: {
        peerId: true,
        cookieName: `${this.$.prefix}Peer`,
        cookieOptions: {
          ttl: this.$.ttl,
          path: this._.prefix,
          encoding: "none",
          isHttpOnly: true,
          isSecure: false,
          clearInvalid: false,
          strictHeader: true,
          isSameSite: this.$.samesite !== "none" ? this.$.samesite : false
        }
      }
    });
    /*  provide client IP address  */

    server.ext("onRequest", async (request, h) => {
      let clientAddress = "<unknown>";
      if (request.headers["x-forwarded-for"]) clientAddress = request.headers["x-forwarded-for"].replace(/^(\S+)(?:,\s*\S+)*$/, "$1");else clientAddress = request.info.remoteAddress;
      request.app.clientAddress = clientAddress;
      return h.continue;
    });
    /*  prepare for JSONWebToken (JWT) authentication  */

    let jwtKey = this.$.secret;
    await server.register({
      plugin: _hapiAuthJwt.default
    });
    server.auth.strategy("jwt", "jwt", {
      key: jwtKey,
      verifyOptions: {
        algorithms: ["HS256"]
      },
      urlKey: `${this.$.prefix}Token`,
      cookieKey: `${this.$.prefix}Token`,
      tokenType: "JWT",
      validate: (decoded, request, h) => {
        let result = this.hook("jwt-validate", "pass", {
          error: null,
          result: true
        }, decoded, request);
        return {
          isValid: result.result,
          error: result.error
        };
      }
    });

    this._.jwtSign = (data, expires) => _jsonwebtoken.default.sign(data, jwtKey, {
      algorithm: "HS256",
      expiresIn: expires || "365d"
    });
    /*  log all requests  */


    server.events.on("response", request => {
      let traffic = request.traffic();
      let protocol = `HTTP/${request.raw.req.httpVersion}`;
      let ws = request.websocket();

      if (ws.mode === "websocket") {
        let wsVersion = ws.ws.protocolVersion || request.headers["sec-websocket-version"] || "13?";
        protocol = `WebSocket/${wsVersion}+${protocol}`;
      }

      let msg = "request: " + "remote=" + `${request.app.clientAddress}:${request.info.remotePort}` + ", " + "method=" + request.method.toUpperCase() + ", " + "url=" + request.url.pathname + ", " + "protocol=" + protocol + ", " + "response=" + (request.response ? request.response.statusCode : "<unknown>") + ", " + "recv=" + traffic.recvPayload + "/" + traffic.recvRaw + ", " + "sent=" + traffic.sentPayload + "/" + traffic.sentRaw + ", " + "duration=" + traffic.timeDuration;
      this.debug(2, `HAPI: request: ${msg}`);
    });
    server.events.on({
      name: "request",
      channels: ["error"]
    }, (request, event, tags) => {
      if (event.error instanceof Error) this.debug(2, `HAPI: request-error: ${event.error.message}`);else this.debug(2, `HAPI: request-error: ${event.error}`);
    });
    server.events.on("log", (event, tags) => {
      if (tags.error) {
        let err = event.error;
        if (err instanceof Error) this.debug(2, `HAPI: log: ${err.message}`);else this.debug(2, `HAPI: log: ${err}`);
      }
    });
    /*  display network interaction information  */

    const displayListenHint = ([scheme, proto]) => {
      let url = `${scheme}://${this._.url.hostname}:${this._.url.port}`;
      this.debug(1, `HAPI: listen on ${url} (${proto})`);
    };

    displayListenHint(withTLS ? ["https", "HTTP/{1.0,1.1,2.0} + SSL/TLS"] : ["http", "HTTP/{1.0,1.1}"]);
    displayListenHint(withTLS ? ["wss", "WebSockets + SSL/TLS"] : ["ws", "WebSockets"]);
    /*  setup services  */

    await _graphqlIo2Ui.default.start.call(this);
    await _graphqlIo3Auth.default.start.call(this);
    await _graphqlIo4Graphql.default.start.call(this);
    await _graphqlIo5Blob.default.start.call(this);
    /*  allow application to hook into  */

    await this.hook("server-start", "promise", server);
    /*  start the HAPI service  */

    return new _promise.default((resolve, reject) => {
      server.start().then(() => {
        this.debug(1, "HAPI: OK: started HAPI service");
        resolve();
      }).catch(err => {
        this.debug(1, "HAPI: ERROR: failed to start HAPI service");
        reject(err);
      });
    });
  }
  /*  stop the service  */


  async stop() {
    /*   stop the HAPI service  */
    this.debug(1, "HAPI: gracefully stopping HAPI service");
    await this._.server.stop({
      timeout: 4 * 1000
    });
    /*  allow application to hook into  */

    await this.hook("server-stop", "promise", this._.server);
    /*  teardown services  */

    await _graphqlIo5Blob.default.stop.call(this);
    await _graphqlIo4Graphql.default.stop.call(this);
    await _graphqlIo3Auth.default.stop.call(this);
    await _graphqlIo2Ui.default.stop.call(this);
    /*  stop listening  */

    this._.listener.close();
    /*  finally destroy HAPI instance  */


    this._.server = null;
  }

}

exports.default = Server;
